/* src/config_clp.h.  Generated by configure.  */
/* src/config_clp.h.in.  */

/* Define to 1, 2, 3, or 4 if Aboca should be build. */
/* #undef CLP_HAS_ABC */

/* Version number of project */
#define CLP_VERSION "1.17.7"

/* Major Version number of project */
#define CLP_VERSION_MAJOR 1

/* Minor Version number of project */
#define CLP_VERSION_MINOR 17

/* Release Version number of project */
#define CLP_VERSION_RELEASE 7
